@@ -1,4 +1,3 @@
-import asyncio
 import json
 import logging
 
@@ -13,7 +12,7 @@ class GSCNodeFunctionReceiverSocket:
         self = GSCNodeFunctionReceiverSocket()
         self.sio = sio
         self.gsdbs = gsdbs
-        self._pool = Pool(self._gsdbs.credentials["poolsize"])
+        self._pool = Pool(self.gsdbs.credentials["poolsize"])
         self.oncnodefunction = oncnodefunction
         self._logger = logging.getLogger(__name__)
 
@@ -31,7 +30,6 @@ class GSCNodeFunctionReceiverSocket:
         def oncnodefunction(id, msg):
             self._pool.apply_async(self.oncnodefunction, args=[self.gsdbs, id, ujson.loads(msg)], callback=on_success,
                                    error_callback=on_errorPost)
-            # self.oncnodefunction(self.gsdbs, id, ujson.loads(msg))
 
         connectURL = ""
 
